@@ -2,6 +2,7 @@
 # License, v. 2.0. If a copy of the MPL was not distributed with this
 # file, You can obtain one at http://mozilla.org/MPL/2.0/.
 """prefpicker module"""
+
 from __future__ import annotations
 
 from datetime import datetime, timezone
@@ -9,12 +10,15 @@ from importlib.metadata import PackageNotFoundError, version
 from json import dumps
 from pathlib import Path
 from random import choice
-from typing import Any, Dict, Iterator, List, Union
+from typing import TYPE_CHECKING, Any, Union
 
 from yaml import safe_load
 from yaml.parser import ParserError
 from yaml.scanner import ScannerError
 
+if TYPE_CHECKING:
+    from collections.abc import Generator
+
 __author__ = "Tyson Smith"
 __credits__ = ["Tyson Smith"]
 try:
@@ -30,8 +34,7 @@ class SourceDataError(Exception):
 
 # Python <= 3.9 requires the use of Union
 PrefValue = Union[bool, int, str, None]
-# Python 3.8 requires typing.Dict and typing.List even with __future__.annotations here
-PrefVariant = Dict[str, List[PrefValue]]
+PrefVariant = dict[str, list[PrefValue]]
 
 
 class PrefPicker:  # pylint: disable=missing-docstring
@@ -41,7 +44,7 @@ class PrefPicker:  # pylint: disable=missing-docstring
         self.prefs: dict[str, dict[str, PrefVariant]] = {}
         self.variants: set[str] = {"default"}
 
-    def check_combinations(self) -> Iterator[tuple[str, int]]:
+    def check_combinations(self) -> Generator[tuple[str, int]]:
         """Count the number of combinations for each variation. Only return
            variants that have more than one combination.
 
@@ -63,7 +66,7 @@ class PrefPicker:  # pylint: disable=missing-docstring
             if count > 1:
                 yield (variant, count)
 
-    def check_duplicates(self) -> Iterator[tuple[str, str]]:
+    def check_duplicates(self) -> Generator[tuple[str, str]]:
         """Look for variants with values that appear more than once per variant.
 
         Args:
@@ -78,7 +81,7 @@ class PrefPicker:  # pylint: disable=missing-docstring
                 if len(variants[variant]) != len(set(variants[variant])):
                     yield (pref, variant)
 
-    def check_overwrites(self) -> Iterator[tuple[str, str, PrefValue]]:
+    def check_overwrites(self) -> Generator[tuple[str, str, PrefValue]]:
         """Look for variants that overwrite the default with the same value.
 
         Args:
@@ -185,7 +188,7 @@ class PrefPicker:  # pylint: disable=missing-docstring
         return picker
 
     @staticmethod
-    def templates() -> Iterator[Path]:
+    def templates() -> Generator[Path]:
         """Available YAML template files.
 
         Args:
